# CrossTraffic - Homepage

Welcome to the CrossTraffic documentation hub! This site serves as the central resource for all things related to the CrossTraffic project, including guides, API references, and more.

API references live on docs.rs per crate.

- Code: <https://github.com/crosstraffic/transportations-library>
- API: <https://docs.rs/transportations-library>
